==> zio-aws-globalaccelerator_2.13-5.17.150.1-sources.jar: zio/aws/globalaccelerator/model/CreateCustomRoutingAcceleratorResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateCustomRoutingAcceleratorResponse(
    accelerator: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse = {
    import CreateCustomRoutingAcceleratorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
      .builder()
      .optionallyWith(accelerator.map(value => value.buildAwsValue()))(
        _.accelerator
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
      .wrap(buildAwsValue())
}
object CreateCustomRoutingAcceleratorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse =
      zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse(
        accelerator.map(value => value.asEditable)
      )
    def accelerator: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ]
    def getAccelerator: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ] = AwsError.unwrapOptionField("accelerator", accelerator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ) extends zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly {
    override val accelerator: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ] = scala
      .Option(impl.accelerator())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingAccelerator.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ): zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.17.280.1-sources.jar: zio/aws/globalaccelerator/model/CreateCustomRoutingAcceleratorResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateCustomRoutingAcceleratorResponse(
    accelerator: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse = {
    import CreateCustomRoutingAcceleratorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
      .builder()
      .optionallyWith(accelerator.map(value => value.buildAwsValue()))(
        _.accelerator
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
      .wrap(buildAwsValue())
}
object CreateCustomRoutingAcceleratorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse =
      zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse(
        accelerator.map(value => value.asEditable)
      )
    def accelerator: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ]
    def getAccelerator: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ] = AwsError.unwrapOptionField("accelerator", accelerator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ) extends zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly {
    override val accelerator: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAccelerator.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.accelerator())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingAccelerator.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse
  ): zio.aws.globalaccelerator.model.CreateCustomRoutingAcceleratorResponse.ReadOnly =
    new Wrapper(impl)
}
